<?php
	/**
	 * Copyright (c) 2008- Samuli Jrvel
	 *
	 * All rights reserved. This program and the accompanying materials
	 * are made available under the terms of the Eclipse Public License v1.0
	 * which accompanies this distribution, and is available at
	 * http://www.eclipse.org/legal/epl-v10.html. If redistributing this code,
	 * this entire header must remain intact.
	 */
	
	/* For configuration instructions, see ReadMe.txt or wiki page at http://code.google.com/p/mollify/wiki/Installation */
	
	$CONFIGURATION_PROVIDER = 'mysql';
	
	$DB_HOST = "localhost";		/* optional, default is "localhost" */
	$DB_DATABASE = "mollify";	/* optional, default is "mollify" */
	$DB_USER = "mollify";
	$DB_PASSWORD = "mollify";

	$SETTINGS = array(
		"timezone" => "Europe/Helsinki"	// change this to match your timezone
	);

?>